# mcp variables

${env:NAME} environment variables
${userHome} path to your home folder
${workspaceFolder} project root (the folder that contains .cursor/mcp.json)
${workspaceFolderBasename} name of the project root
${pathSeparator} and ${/} OS path separator
